@@ -9,6 +9,7 @@ import json
 import yaml
 import openapi_spec_validator
 import jsonpath_ng
+import inspect
 
 try:
     from typing import Union, Dict, List, Any, Literal
@@ -39,11 +40,6 @@ class Bundler(object):
     def literal_representer(dumper, data):
         return dumper.represent_scalar(u"tag:yaml.org,2002:str", data, style="|")
 
-    @staticmethod
-    def yaml_key_mapping(self, node, deep=False):
-        data = self.construct_mapping_org(node, deep)
-        return {(str(key) if isinstance(key, int) else key): data[key] for key in data}
-
     def __init__(self, api_files, output_dir="./"):
         self._parsers = {}
         self._api_files = api_files
@@ -54,9 +50,8 @@ class Bundler(object):
         self._content = {}
         self._includes = {}
         self._resolved = []
+        self._errors = []
         yaml.add_representer(Bundler.description, Bundler.literal_representer)
-        yaml.SafeLoader.construct_mapping_org = yaml.SafeLoader.construct_mapping
-        yaml.SafeLoader.construct_mapping = Bundler.yaml_key_mapping
 
     def _get_parser(self, pattern):
         if pattern not in self._parsers:
@@ -71,6 +66,7 @@ class Bundler(object):
         return self._output_filename
 
     def bundle(self):
+        self._errors = []
         self._output_filename = os.path.join(self._output_dir, "openapi.yaml")
         self._json_filename = os.path.join(self._output_dir, "openapi.json")
         self._content = {}
@@ -88,12 +84,18 @@ class Bundler(object):
         self._remove_x_include()
         self._resolve_license()
         self._resolve_strings(self._content)
+        self._resolve_keys(self._content)
+        self._validate_errors()
         with open(self._output_filename, "w") as fp:
             yaml.dump(self._content, fp, indent=2, allow_unicode=True, line_break="\n", sort_keys=False)
         with open(self._json_filename, "w") as fp:
             fp.write(json.dumps(self._content, indent=4))
         self._validate_file()
 
+    def _validate_errors(self):
+        if len(self._errors) > 0:
+            raise TypeError("\n".join(self._errors))
+
     def _validate_file(self):
         print("validating {}...".format(self._output_filename))
         with open(self._output_filename) as fid:
@@ -148,9 +150,14 @@ class Bundler(object):
                     if "type" in property_obj:
                         proprty_type = property_obj["type"]
                         if proprty_type == "object":
-                            errors.append(f" \n*** Unsupported. Property '{component_name}'.'{property_name}' is a nested component ***")
+                            errors.append(
+                                "\n*** Unsupported. Property '{}'.'{}' is a nested component ***".format(
+                                    component_name,
+                                    property_name,
+                                )
+                            )
         if len(errors) > 0:
-            raise TypeError(''.join(errors))
+            raise TypeError("".join(errors))
 
     def _resolve_refs(self, base_dir, yobject):
         """Resolving references is relative to the current file location"""
@@ -175,11 +182,45 @@ class Bundler(object):
                             self._resolve_refs(base_dir, include)
                             self._includes[include_ref] = include
                 else:
+                    self._length_restriction(value)
+                    self._required_restriction(key, value)
                     self._resolve_refs(base_dir, value)
         elif isinstance(yobject, list):
             for item in yobject:
                 self._resolve_refs(base_dir, item)
 
+    def _length_restriction(self, value):
+        restricted_keys = {
+            "length", "minimum", "maximum", "minLength", "maxLength"
+        }
+        if isinstance(value, dict):
+            intersect_keys = restricted_keys.intersection(set(value.keys()))
+            if len(intersect_keys) > 0 and "format" in value.keys() and \
+                    value["format"] in ["ipv4", "ipv6", "mac"]:
+                stacks = inspect.stack()
+                property = "{}/{}/{}".format(
+                    stacks[3].frame.f_locals["key"] if "key" in stacks[3].frame.f_locals else "",
+                    stacks[2].frame.f_locals["key"] if "key" in stacks[2].frame.f_locals else "",
+                    stacks[1].frame.f_locals["key"]
+                )
+                self._errors.append("Property {property} should not contain {keys} with format {format}".format(
+                    property=property,
+                    keys=intersect_keys,
+                    format=value["format"]
+                ))
+
+    def _required_restriction(self, schema_name, value):
+        expected_set = {"required", "properties"}
+        if isinstance(value, dict) and expected_set.issubset(value.keys()):
+            if isinstance(value["required"], list):
+                for required in value["required"]:
+                    if "default" in value["properties"][required].keys():
+                        self._errors.append("Property {property} within schema {name} have "
+                                            "both required as well as default".format(
+                            property=required,
+                            name=schema_name
+                        ))
+
     def _resolve_x_pattern(self, pattern_extension):
         """Find all instances of pattern_extension in the openapi content
         and generate a #/components/schemas/... pattern schema object that is
@@ -222,7 +263,6 @@ class Bundler(object):
         schema = {
             "description": description,
             "type": "object",
-            "required": ["choice"],
             "properties": {
                 "choice": {
                     "description": "The type of checksum",
@@ -445,6 +485,17 @@ class Bundler(object):
         elif "name" not in self._content["info"]["license"]:
             raise Exception("The following properties are REQUIRED: license.name")
 
+    def _resolve_keys(self, content):
+        changes = {}
+        for key, value in content.items():
+            if isinstance(key, int):
+                changes[key] = value
+            if isinstance(value, dict):
+                self._resolve_keys(value)
+        for key, value in changes.items():
+            content[str(key)] = value
+            del content[key]
+
 
 if __name__ == "__main__":
     Bundler(api_files=["./tests/api/api.yaml"]).bundle()
